@@ -211,6 +211,7 @@ draw.spikes <- function (t, tmin, tmax,
 summary.mm.s <- function(object, ...) {
   cat(paste("Spike data:", object$file, "\n"))
   cat(paste("NCells", object$NCells, "\n"))
+  cat(sprintf("Time (s) [%.3f %.3f]\n", object$rec.time[1], object$rec.time[2]))
 }
 
 read.spikes <- function(reader, ...) {
@@ -459,20 +460,22 @@ shuffle.spike.times <- function (s, noise.sd) {
 }
 
 
-fourplot <- function(s) {
+fourplot <- function(s, names=FALSE) {
   ## Simple 2x2 summary plot of an "s" structure.
   old.par <- par(no.readonly = TRUE)
   on.exit(par(old.par))
   
-  par(mfrow=c(2,2))
-  plot(s$layout)                             #show layout of electrodes.
-  plot.meanfiringrate(s)
-  plot(s)                                 #plot the spikes.
+  par(mfrow=c(2,2), oma=c(0,0,2,0), las=1)
+  
+  plot(s$layout, use.names=names)                        #show layout of electrodes.
+  plot.meanfiringrate(s, main='')
+  plot(s, main='', label.cells=names, use.names=names)                      #plot the spikes.
 
   ##   if	(!is.na(s$corr$corr.indexes[1])) {
   if( any(names(s)=="corr")) {
-    plot.corr.index(s)
+    plot.corr.index(s, main='')
   }
+  mtext(basenamepy(s$file)$base, side=3, outer=T)
 }
 
 
@@ -1169,7 +1172,7 @@ check.spikes.monotonic <- function(spikes) {
 }
   
 
-spikes.to.bursts <- function(spikes, burst.sep=2) {
+mm.spikes.to.bursts <- function(spikes, burst.sep=2) {
   ## Convert spikes to bursts.
   ## burst.sep is the threshold time between spikes for finding bursts.
   ## spikes.to.bursts(c(1,2,3, 7,8, 11,12,13,14, 19,20, 23,24))
@@ -2255,12 +2258,12 @@ op.picture <- function(pos, rates, iteration) {
 }
 
 
-plot.mealayout <- function(x, ...) {
+plot.mealayout <- function(x, use.names=FALSE, ...) {
   ## Decide which function to plot the array layout based on number of cells.
-  if (nrow(x$pos) < 200) {
-    plot.mealayout.1(x, ...)
+  if (nrow(x$pos) < 100) {
+    plot.mealayout.1(x, use.names, ...)
   } else {
-    plot.mealayout.hi(x, ...)
+    plot.mealayout.hi(x, use.names, ...)
   }
 }
     
@@ -2273,7 +2276,7 @@ plot.mealayout.1 <- function(x, use.names=FALSE, ...) {
   plot(NA, asp=1,
        xlim=x$xlim, ylim=x$ylim,
        bty="n",
-       xlab="", ylab="", type="n")
+       xlab="spacing (µm)", ylab="", type="n")
   if (use.names)
     text(pos[,1], pos[,2], rownames(pos), ...)
   else
@@ -2286,7 +2289,7 @@ plot.mealayout.hi <- function(x, use.names=FALSE, ...) {
   plot(pos, asp=1,
        xlim=x$xlim, ylim=x$ylim,
        bty="n",
-       xlab="", ylab="", pch=20)
+       xlab="spacing (µm)", ylab="", pch=20)
 }
 
 spikes.to.ragged.csv <- function(spikes, filename='test.csv') {
